#line 2 "sieve/sieve-lex.c"

#line 4 "sieve/sieve-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer sieve_create_buffer
#define yy_delete_buffer sieve_delete_buffer
#define yy_flex_debug sieve_flex_debug
#define yy_init_buffer sieve_init_buffer
#define yy_flush_buffer sieve_flush_buffer
#define yy_load_buffer_state sieve_load_buffer_state
#define yy_switch_to_buffer sieve_switch_to_buffer
#define yyin sievein
#define yyleng sieveleng
#define yylex sievelex
#define yylineno sievelineno
#define yyout sieveout
#define yyrestart sieverestart
#define yytext sievetext
#define yywrap sievewrap
#define yyalloc sievealloc
#define yyrealloc sieverealloc
#define yyfree sievefree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE sieverestart(sievein  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int sieveleng;

extern FILE *sievein, *sieveout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE sievelex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-sievelineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < sieveleng; ++yyl )\
                    if ( sievetext[yyl] == '\n' )\
                        --sievelineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --sievelineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up sievetext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up sievetext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via sieverestart()), so that the user can continue scanning by
	 * just pointing sievein at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when sievetext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int sieveleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow sievewrap()'s to do buffer switches
 * instead of setting up a fresh sievein.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void sieverestart (FILE *input_file  );
void sieve_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE sieve_create_buffer (FILE *file,int size  );
void sieve_delete_buffer (YY_BUFFER_STATE b  );
void sieve_flush_buffer (YY_BUFFER_STATE b  );
void sievepush_buffer_state (YY_BUFFER_STATE new_buffer  );
void sievepop_buffer_state (void );

static void sieveensure_buffer_stack (void );
static void sieve_load_buffer_state (void );
static void sieve_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER sieve_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE sieve_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE sieve_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE sieve_scan_bytes (yyconst char *bytes,int len  );

void *sievealloc (yy_size_t  );
void *sieverealloc (void *,yy_size_t  );
void sievefree (void *  );

#define yy_new_buffer sieve_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        sieveensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            sieve_create_buffer(sievein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        sieveensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            sieve_create_buffer(sievein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define sievewrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *sievein = NULL, *sieveout = NULL;

typedef int yy_state_type;

extern int sievelineno;

int sievelineno = 1;

extern char *sievetext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr sievetext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yynoreturn yy_fatal_error (yyconst char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up sievetext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	sieveleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 171
#define YY_END_OF_BUFFER 172
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[941] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  172,  170,  169,  169,
        7,  168,  170,    8,  170,  170,  170,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
      170,  170,  170,    5,    5,    5,    3,    5,   32,   32,
      170,   72,   72,  170,  121,  121,  170,   91,   91,  170,
      171,  170,  168,    0,    8,    8,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    9,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    2,    2,    1,    4,    0,   36,
        0,    0,   79,    0,    0,    0,    0,    0,  125,    0,
        0,    0,    0,   93,    0,    0,  107,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  128,    0,    0,   37,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  160,
        0,    0,    0,   19,    0,    0,    0,    0,    0,    0,
       55,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  122,  123,
      124,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  167,    0,   44,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  157,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,  129,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   50,    0,    0,  145,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   49,    0,   87,    0,    0,    0,    0,   11,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   27,    0,   85,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   23,    0,    0,   13,    0,
        0,   18,    0,    0,    0,    0,    0,   73,   76,   75,
       78,   77,   74,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  167,    0,    0,    0,
        0,    0,    0,    0,   30,    0,    0,   63,    0,    0,
        0,    0,   66,    0,    0,    0,  131,    0,    0,  109,
        0,   42,    0,    0,    0,    0,    0,    0,   68,    0,
        0,  150,    0,    0,   24,    0,    0,    0,    0,    0,
        0,    0,   51,    0,    0,    0,   47,    0,    0,   89,
        0,    0,    0,   15,   14,    0,    0,    0,    0,    0,
       10,    0,    0,    0,  133,    0,   17,    0,    0,    0,
      132,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   96,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   70,    0,    0,    0,    0,   84,    0,
        0,    0,    0,  108,    0,    0,   56,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   40,    0,    0,
        0,    0,   25,    0,   57,   71,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   16,    0,
        0,   20,    0,    0,    0,    0,  116,    0,  112,    0,

        0,  151,    0,    0,  162,    0,   54,    0,    6,    6,
        0,   86,    0,    0,    0,    0,    0,   97,   99,    0,
        0,    0,    0,    0,    0,    0,  102,    0,   94,  105,
        0,   99,   97,   94,   94,    0,    0,    0,  142,    0,
        0,    0,    0,    0,  135,   48,   46,    0,  148,   67,
      153,    0,   61,    0,    0,    0,    0,    0,  127,  130,
      144,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   81,    0,   21,    0,    0,    0,   26,
        0,    0,    0,  113,    0,   83,  146,    0,    0,    0,
        0,    0,    0,   12,    0,   80,    0,    0,    6,    0,

        0,    0,    0,    0,   92,    0,    0,    0,   95,    0,
      104,    0,    0,    0,    0,    0,    0,    0,  143,    0,
        0,   52,    0,    0,    0,    0,  163,   39,  118,    0,
      117,    0,    0,    0,    0,    0,   69,    0,   65,    0,
        0,    0,    0,    0,    0,  126,    0,   22,    0,   28,
        0,    0,    0,  136,    0,   29,    0,    0,    0,    6,
       62,    0,    0,    0,    0,    0,   98,  100,  101,    0,
       98,  164,    0,    0,    0,    0,   38,    0,    0,    0,
        0,    0,  149,    0,  147,    0,    0,    0,    0,  154,
        0,  166,  110,    0,    0,  152,    0,  161,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,   33,  103,
      106,   64,    0,    0,    0,  119,    0,   45,    0,  159,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   82,    0,    0,    0,    0,    0,    0,
        0,    0,   31,  120,   58,    0,   41,    0,    0,  156,
       59,   90,    0,   53,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  165,  111,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   88,    0,  134,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   60,    0,  137,    0,

      138,    0,   43,    0,    0,    0,  141,  140,  158,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  155,    0,   34,   35,    0,    0,    0,
        0,    0,  115,    0,  139,    0,    0,    0,  114,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    7,    8,    1,    9,   10,   11,   12,   13,   14,
       15,   16,   16,   17,   18,   19,   18,   20,   21,    1,
        1,    1,    1,    1,   22,    1,   23,   24,   25,    1,
       26,   27,   28,   29,   30,   31,   32,   33,   34,    1,
        1,   35,   36,   37,   38,    1,   39,    1,   40,   41,
        1,   42,    1,    1,   43,    1,   44,   45,   46,   47,

       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,   60,   61,   62,   63,   64,   65,   66,   67,
       68,   69,    1,   70,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[71] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[951] =
    {   0,
        0,    0, 1433,   68,   69,   70,  111,    0,   77,   81,
       85,   89,   93,   97,  101,  105, 1435, 1437, 1437, 1437,
     1437,    0, 1427,  165,  178,   85, 1375, 1368,   89,  131,
       91,   90,   95, 1375, 1382, 1371,  101, 1370, 1379,  137,
      100, 1369, 1381, 1437, 1437,  198, 1437,    0, 1437, 1437,
      164, 1437, 1437,  198, 1437, 1437,  199, 1437, 1437,  201,
     1437,  267,    0, 1417,    0, 1437,   92, 1355,   60,  201,
     1365,  144, 1366,  206,  204,  221,  226, 1362,  223, 1371,
     1354,  106,  204, 1369,  205, 1372, 1367, 1356, 1366, 1357,
     1343, 1363, 1348, 1345,  163, 1345, 1347, 1343, 1339,  228,

     1351, 1347, 1346, 1338, 1355, 1437, 1354, 1351, 1352, 1347,
     1344,  225, 1330, 1329,  268,  220, 1322, 1332, 1341,  229,
     1321, 1323, 1330,  246, 1437, 1382, 1437, 1437, 1379, 1437,
      115, 1378, 1437,  251,  292,  293,   71, 1377, 1437, 1376,
     1375, 1374, 1373, 1437,  297, 1372, 1437,  295,  288,  280,
      300,  320,  338,  321,  346,  352,  327,  418, 1369,  200,
     1328, 1319,  271,  288, 1325, 1304, 1308, 1314, 1323, 1322,
     1323, 1308, 1307, 1307, 1319, 1312, 1437, 1302, 1313, 1437,
     1297, 1301, 1295,  105,  316,  169, 1300,  299, 1309, 1291,
     1301, 1304, 1290, 1292, 1283,  303, 1302, 1299, 1301, 1278,

      322, 1285, 1295, 1287, 1293, 1283,  331, 1281, 1280, 1269,
     1275, 1287, 1286, 1275, 1286, 1276,  335,  336, 1277, 1271,
     1266, 1265, 1278, 1276, 1277, 1258, 1267, 1262, 1261, 1437,
     1264, 1264, 1273, 1264, 1263, 1266, 1255, 1248, 1247, 1245,
     1260, 1260, 1249, 1260, 1246, 1252, 1240, 1254, 1257, 1256,
     1247,  362, 1293, 1292, 1291, 1290, 1289, 1288, 1437, 1437,
     1437,  412,  397,  371,  399,  408,  388,  414,  439,  413,
      391,  427,  443,  480,  472,  474,  481,  482,  484,  550,
      388, 1437,  349, 1437, 1234,  351, 1232, 1227, 1221, 1231,
     1243, 1224, 1241, 1240, 1225, 1437, 1232, 1225, 1235, 1232,

     1231, 1226, 1218, 1227, 1211, 1223, 1209, 1227, 1222, 1214,
     1222, 1205, 1215, 1217, 1208, 1211, 1214, 1209, 1210, 1198,
     1196, 1194, 1437, 1208, 1197, 1437, 1196, 1207, 1199, 1188,
     1202, 1189, 1200, 1186, 1182, 1191, 1196, 1188, 1194, 1193,
     1191, 1190, 1437, 1190, 1437, 1174, 1173, 1191, 1182, 1437,
     1184, 1177, 1170, 1182, 1168, 1165, 1179, 1174, 1170, 1176,
     1175, 1158, 1161, 1437, 1175, 1437, 1172, 1169, 1156, 1170,
     1150, 1162, 1152, 1164, 1156, 1437, 1141, 1157, 1437, 1151,
     1187, 1437, 1145, 1142, 1157,  402,  444, 1437, 1437, 1437,
     1437, 1437, 1437,  521,  495, 1198,  541,  486,  493,  525,

      540,  554,  562,  506,  376,  558,  596,  597,  488,  598,
      604,  625,  624,  651,  654,  720, 1195, 1146, 1152, 1152,
     1142, 1153, 1152,  513, 1437, 1132, 1131, 1437, 1141, 1140,
     1144, 1128, 1437, 1145, 1133, 1139, 1437, 1125, 1118, 1437,
     1121, 1437, 1128, 1121, 1136, 1129, 1135, 1120, 1437, 1133,
     1127, 1437, 1117, 1122, 1437, 1115, 1124, 1104, 1105, 1112,
     1116, 1119, 1437, 1105, 1101, 1103, 1437, 1115, 1115, 1437,
     1117, 1116, 1097, 1437, 1437, 1101, 1109, 1104, 1094, 1108,
     1437, 1095, 1094, 1105, 1437, 1088, 1437, 1092, 1104, 1086,
     1437, 1099, 1081, 1086, 1099, 1074, 1093, 1077, 1091, 1077,

     1080, 1075, 1091, 1086, 1089, 1082,  639, 1077, 1078, 1086,
      514,  212,  691, 1123, 1437, 1122,  563,  631,  679,  630,
      693,  607,  497, 1121,  666, 1120, 1119,  729,  710,  724,
      738,  755, 1118, 1117,  821, 1077, 1058, 1071, 1070, 1071,
     1055, 1063, 1057, 1437, 1065, 1057, 1054, 1062, 1437, 1054,
     1060, 1046, 1043, 1437, 1054, 1045, 1054, 1044, 1053, 1050,
     1052, 1043, 1029, 1039, 1038, 1037,  586, 1437, 1045, 1045,
     1047, 1044, 1437, 1041, 1039, 1437, 1043, 1036, 1038, 1022,
     1020, 1031, 1032, 1033, 1035, 1019, 1020, 1013, 1437, 1012,
     1024, 1437, 1025, 1024, 1004, 1007, 1026, 1022, 1437, 1018,

     1018, 1437, 1009, 1014, 1437, 1008, 1437,  794, 1437, 1059,
      309, 1437, 1003,  357,  527,  632, 1055, 1437, 1437,  496,
      754,  721, 1054,  780,  783, 1053, 1437,  790, 1437, 1437,
      797, 1437, 1437, 1437, 1437,  852, 1007,  994, 1437,  126,
     1007, 1010,  996,  989, 1437, 1437, 1437,  987, 1437, 1437,
     1437, 1006, 1437, 1005,  996,  980,  984,  997, 1437, 1437,
     1437,  571, 1000,  999,  994,  989,  991,  977,  983,  974,
      984,  983,  966, 1437,  985, 1437,  985,  983,  962, 1437,
      966,  980,  971, 1437,  968, 1437, 1437,  964,  630,  980,
      967,  959,  966, 1437,  972, 1437,  955,  566,  582,  961,

      950,  958,  617,  665, 1437,  680, 1010, 1009, 1437, 1008,
     1437,  761,  811,  812,  950,  963,  965,  961, 1437,  945,
      945, 1437,  945,  948,  943,  942,  950, 1437, 1437,  946,
     1437,  945,  944,  948,  942,  941, 1437,  931, 1437,  947,
      932,  930,  930,  946,  945, 1437,  940, 1437,  939, 1437,
      918,  918,  937,  935,  934, 1437,  937,  917,  917, 1437,
     1437,  915,  914,  714,  971,  970, 1437, 1437, 1437,  969,
     1437, 1437,  911,  910,  916,  912, 1437,  914,  922,  904,
      904,  918, 1437,  895, 1437,  915,  915,  917,  898, 1437,
      897, 1437, 1437,  878,  893, 1437,  882, 1437,  886,  889,

      869,  872,  884,  889,  884,  888,  877,  747, 1437, 1437,
     1437, 1437,  870,  883,  865, 1437,  877, 1437,  861, 1437,
      865,  854,  873,  868,   29,  130,  209,  363,  379,  391,
      401,  440,  444, 1437,  471,  481,  507,  544,  678,  706,
      564,  568, 1437, 1437, 1437,  591, 1437,  610,  593, 1437,
     1437, 1437,  599, 1437,  634,  675,  669,  674,  691,  689,
      686,  672,  774,  759,  677,  709,  719,  710, 1437, 1437,
      715,  741,  746,  763,  750,  747,  758,  779,  818,  822,
      769,  768, 1437,  788, 1437,  774,  776,  796,  796,  790,
      783,  791,  850,  844,  808,  811, 1437,  799, 1437,  816,

      815,  802, 1437,  821,  866,  868, 1437, 1437, 1437,  831,
      816,  823,  824,  883,  884,  831,  840,  831,  843,  890,
      892,  854,  839, 1437,  844, 1437, 1437,  858,  841,  860,
      856,  849, 1437,  857, 1437,  861,  851,  847, 1437, 1437,
      942,  915,  916,  944,  946,  948,  950,  952,  954,  956
    } ;

static yyconst flex_int16_t yy_def[951] =
    {   0,
      940,    1,  941,  941,  941,  941,    1,    7,    7,    7,
        7,    7,    7,    7,    7,    7,  940,  940,  940,  940,
      940,  942,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  943,  940,  940,
      944,  940,  940,  945,  940,  940,  946,  940,  940,  947,
      940,  948,  942,  949,   24,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  944,  940,
      944,  945,  940,  945,  945,  945,  945,  946,  940,  946,
      946,  946,  947,  940,  947,  948,  940,  948,  948,  948,
      948,  948,  948,  948,  948,  948,  948,  948,  949,  949,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  944,  945,  945,  945,  945,  945,  945,  940,  940,
      940,  947,  948,  948,  948,  948,  948,  948,  948,  948,
      948,  948,  948,  948,  948,  948,  948,  948,  948,  948,
      949,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  944,  944,  940,  940,  940,
      940,  940,  940,  947,  948,  948,  948,  948,  948,  948,

      948,  948,  948,  948,  948,  948,  948,  948,  948,  948,
      948,  948,  948,  948,  948,  948,  949,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      944,  944,  947,  948,  940,  948,  948,  948,  948,  948,
      948,  948,  948,  948,  948,  948,  948,  948,  948,  948,
      948,  948,  948,  948,  948,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      950,  940,  940,  940,  944,  944,  947,  940,  940,  948,
      948,  948,  948,  948,  948,  948,  940,  948,  940,  940,
      948,  940,  940,  940,  940,  948,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  950,  950,  940,

      940,  940,  944,  944,  940,  948,  948,  948,  940,  948,
      940,  948,  948,  948,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  944,  944,  948,  940,  940,  940,  948,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940,  944,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  944,  944,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  944,  944,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  944,  944,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  944,  944,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  944,  944,  940,  940,  940,  940,
      940,  940,  940,  944,  944,  940,  940,  940,  940,  944,
      944,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,    0,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940
    } ;

static yyconst flex_uint16_t yy_nxt[1508] =
    {   0,
       18,   19,   20,   19,   21,   22,   18,   18,   18,   18,
       23,   24,   24,   24,   24,   24,   24,   24,   24,   25,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   26,   27,   28,   29,   30,   31,   18,
       32,   33,   34,   35,   36,   37,   38,   18,   18,   18,
       39,   40,   41,   42,   43,   18,   18,   18,   18,   18,
       45,   45,   45,   47,   47,  133,  850,   46,   52,   53,
       52,   54,   52,   53,   52,   54,   55,   56,   55,   57,
       55,   56,   55,   57,   58,   59,   58,   60,   58,   59,

       58,   60,   18,   61,   18,   62,   18,   61,   18,   62,
       48,   48,   49,   50,   49,   51,   18,  164,  258,  130,
      165,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   89,   94,  104,  102,  252,   95,  105,  161,   90,
       96,   91,  103,  106,  112,  107,  162,  121,  113,  195,
      308,  108,   97,  196,   18,   18,   18,   18,   18,   18,
      122,   18,   18,   18,   18,   18,   18,   18,  130,  717,
      309,   18,   18,   18,   18,   18,   65,   65,   65,   65,
       65,   65,   65,   65,  116,   98,  718,   99,  117,  170,
       66,  100,  851,  118,   66,  119,   66,  101,  171,  120,

      125,  126,  133,  139,  172,  144,  281,  127,  145,  145,
      282,  140,  141,  142,   66,  131,  130,  213,   66,  214,
       66,   67,   68,   69,   70,   71,   72,   73,   74,   75,
      312,  313,   76,   77,   78,   79,   80,   81,   82,   83,
       84,   85,   86,   87,  166,  134,   88,  135,  167,  174,
      177,  197,  136,  175,  137,  133,  852,  176,  168,  178,
      179,  201,  198,  202,  181,  180,  203,  199,  182,  185,
      145,  147,  183,  186,  616,  219,  231,  187,  184,  189,
      240,  190,  241,  191,  147,  232,  245,  192,  220,  246,
      148,  250,  147,  149,  150,  151,  133,  133,  152,  147,

      251,  144,  153,  154,  147,  155,  156,  157,  262,  262,
      253,  609,  699,  148,  235,  265,  263,  149,  150,  151,
      236,  264,  152,  237,  147,  147,  285,  238,  153,  154,
      239,  147,  155,  286,  156,  157,  158,  266,  263,  254,
      256,  265,  147,  287,  288,  264,  289,  267,  273,  265,
      147,  290,  324,  268,  255,  257,  147,  264,  325,  315,
      276,  316,  270,  266,  263,  326,  130,  310,  331,  266,
      274,  267,  273,  332,  271,  147,  275,  268,  311,  338,
      147,  339,  350,  352,  276,  270,  351,  353,  523,  269,
      273,  340,  147,  274,  160,  147,  276,  418,  417,  275,

      271,  147,  421,  147,  701,  386,  130,  272,  398,  419,
      853,  422,  147,  702,  405,  274,  144,  147,  147,  387,
      401,  275,  147,  394,  394,  394,  394,  394,  394,  394,
      394,  147,  399,  395,  398,  404,  396,  405,  400,  263,
      398,  854,  277,  147,  401,  278,  402,  147,  130,  404,
      405,  279,  855,  265,  271,  266,  399,  401,  404,  395,
      405,  263,  400,  511,  396,  277,  397,  856,  399,  278,
      402,  403,  404,  405,  407,  279,  147,  400,  147,  265,
      271,  266,  404,  402,  147,  147,  147,  280,  147,  512,
      147,  857,  147,  409,  858,  403,  406,  147,  407,  147,

      147,  147,  409,  404,  408,  408,  410,  706,  403,  626,
      147,  517,  407,  407,  401,  409,  413,  859,  130,  514,
      516,  398,  526,  860,  409,  144,  404,  408,  408,  147,
      410,  130,  513,  513,  513,  513,  513,  407,  401,  522,
      413,  409,  514,  410,  147,  515,  516,  398,  526,  408,
      411,  412,  518,  414,  147,  516,  542,  526,  147,  615,
      543,  861,  147,  522,  514,  514,  147,  147,  609,  699,
      523,  409,  404,  405,  408,  522,  518,  519,  703,  620,
      400,  407,  415,  399,  760,  699,  395,  398,  514,  396,
      520,  522,  862,  409,  518,  404,  405,  408,  520,  519,

      147,  147,  147,  519,  400,  407,  415,  399,  147,  519,
      514,  147,  395,  398,  730,  522,  520,  396,  865,  416,
      524,  130,  527,  520,  520,  519,  525,  522,  147,  147,
      866,  521,  731,  525,  147,  147,  130,  522,  526,  625,
      608,  609,  610,  524,  611,  527,  665,  867,  527,  524,
      525,  666,  621,  868,  869,  147,  623,  525,  147,  870,
      520,  522,  519,  625,  526,  524,  525,  527,  764,  130,
      147,  527,  524,  528,  621,  527,  625,  752,  527,  704,
      623,  753,  130,  147,  147,  516,  520,  520,  519,  628,
      520,  519,  766,  530,  529,  144,  871,  147,  527,  623,

      621,  527,  617,  617,  617,  617,  617,  617,  617,  617,
      130,  516,  628,  520,  627,  622,  520,  519,  130,  623,
      531,  863,  808,  532,  515,  147,  872,  765,  630,  622,
      873,  874,  523,  629,  875,  628,  876,  877,  517,  878,
      881,  622,  632,  623,  533,  708,  622,  518,  622,  525,
      623,  130,  628,  522,  534,  622,  520,  519,  147,  630,
      882,  625,  624,  130,  623,  147,  883,  533,  708,  864,
      884,  518,  622,  525,  623,  628,  885,  522,  130,  622,
      534,  623,  520,  519,  709,  625,  707,  147,  623,  535,
      708,  622,  839,  623,  147,  608,  609,  610,  631,  611,

      770,  147,  886,  840,  708,  623,  710,  623,  887,  888,
      707,  712,  889,  890,  880,  769,  771,  622,  712,  891,
      710,  892,  130,  707,  624,  635,  130,  708,  770,  710,
      770,  895,  896,  712,  897,  879,  898,  899,  900,  901,
      712,  902,  621,  710,  628,  903,  904,  623,  130,  708,
      770,  770,  710,  625,  130,  907,  709,  622,  908,  712,
      909,  910,  911,  912,  621,  893,  713,  628,  913,  894,
      130,  623,  130,  712,  916,  710,  708,  625,  770,  770,
      770,  770,  917,  622,  707,  918,  919,  130,  130,  922,
      636,  923,  924,  925,  926,  712,  927,  928,  710,  708,

      929,  930,  931,  932,  906,  905,  933,  934,  707,  914,
      935,  936,  937,  938,  939,   63,  128,  849,  848,  915,
      847,  714,  846,  845,  844,  843,  842,  841,  838,  921,
      837,  836,  835,  834,  833,  832,  831,  830,  829,  828,
      827,  920,   44,   44,  129,  129,  132,  132,  138,  138,
      143,  143,  146,  146,  159,  159,  698,  698,  826,  825,
      824,  823,  822,  821,  820,  819,  818,  817,  816,  815,
      814,  813,  812,  811,  810,  809,  807,  806,  805,  804,
      803,  802,  801,  800,  799,  798,  797,  796,  795,  794,
      793,  792,  791,  790,  789,  788,  787,  786,  785,  784,

      783,  782,  781,  780,  779,  778,  777,  776,  775,  774,
      773,  772,  769,  768,  767,  763,  762,  761,  759,  758,
      757,  756,  755,  754,  751,  750,  749,  748,  747,  746,
      745,  744,  743,  742,  741,  740,  739,  738,  737,  736,
      735,  734,  733,  732,  729,  728,  727,  726,  725,  724,
      723,  722,  721,  720,  719,  716,  715,  711,  709,  705,
      700,  609,  697,  696,  695,  694,  693,  692,  691,  690,
      689,  688,  687,  686,  685,  684,  683,  682,  681,  680,
      679,  678,  677,  676,  675,  674,  673,  672,  671,  670,
      669,  668,  667,  664,  663,  662,  661,  660,  659,  658,

      657,  656,  655,  654,  653,  652,  651,  650,  649,  648,
      647,  646,  645,  644,  643,  642,  641,  640,  639,  638,
      637,  634,  633,  630,  629,  627,  619,  618,  614,  613,
      612,  607,  606,  605,  604,  603,  602,  601,  600,  599,
      598,  597,  596,  595,  594,  593,  592,  591,  590,  589,
      588,  587,  586,  585,  584,  583,  582,  581,  580,  579,
      578,  577,  576,  575,  574,  573,  572,  571,  570,  569,
      568,  567,  566,  565,  564,  563,  562,  561,  560,  559,
      558,  557,  556,  555,  554,  553,  552,  551,  550,  549,
      548,  547,  546,  545,  544,  541,  540,  539,  538,  537,

      536,  160,  515,  510,  509,  508,  507,  506,  505,  504,
      503,  502,  501,  500,  499,  498,  497,  496,  495,  494,
      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      483,  482,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  470,  469,  468,  467,  466,  465,  464,
      463,  462,  461,  460,  459,  458,  457,  456,  455,  454,
      453,  452,  451,  450,  449,  448,  447,  446,  445,  444,
      443,  442,  441,  440,  439,  438,  437,  436,  435,  434,
      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  420,  393,  392,  391,  390,  389,  388,  385,  384,

      383,  382,  381,  380,  379,  378,  377,  376,  375,  374,
      373,  372,  371,  370,  369,  368,  367,  366,  365,  364,
      363,  362,  361,  360,  359,  358,  357,  356,  355,  354,
      349,  348,  347,  346,  345,  344,  343,  342,  341,  337,
      336,  335,  334,  333,  330,  329,  328,  327,  323,  322,
      321,  320,  319,  318,  317,  314,  307,  306,  305,  304,
      303,  302,  301,  300,  299,  298,  297,  296,  295,  294,
      293,  292,  291,  284,  283,  160,  147,  144,  261,  260,
      259,  139,  133,  130,  125,  249,  248,  247,  244,  243,
      242,  234,  233,  230,  229,  228,  227,  226,  225,  224,

      223,  222,  221,  218,  217,  216,  215,  212,  211,  210,
      209,  208,  207,  206,  205,  204,  200,  194,  193,  188,
      173,  169,  163,  160,  124,  123,  115,  114,  111,  110,
      109,   93,   92,   64,  940,   45,   17,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940
    } ;

static yyconst flex_int16_t yy_chk[1508] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        4,    5,    6,    5,    6,  137,  825,    4,    9,    9,
        9,    9,   10,   10,   10,   10,   11,   11,   11,   11,
       12,   12,   12,   12,   13,   13,   13,   13,   14,   14,

       14,   14,   15,   15,   15,   15,   16,   16,   16,   16,
        5,    6,    7,    7,    7,    7,    7,   69,  137,  131,
       69,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,   26,   29,   32,   31,  131,   29,   32,   67,   26,
       29,   26,   31,   33,   37,   33,   67,   41,   37,   82,
      184,   33,   29,   82,    7,    7,    7,    7,    7,    7,
       41,    7,    7,    7,    7,    7,    7,    7,   51,  640,
      184,    7,    7,    7,    7,    7,   24,   24,   24,   24,
       24,   24,   24,   24,   40,   30,  640,   30,   40,   72,
       24,   30,  826,   40,   24,   40,   24,   30,   72,   40,

       46,   46,   54,   57,   72,   60,  160,   46,   60,   60,
      160,   57,   57,   57,   24,   51,  512,   95,   24,   95,
       24,   25,   25,   25,   25,   25,   25,   25,   25,   25,
      186,  186,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   70,   54,   25,   54,   70,   74,
       75,   83,   54,   74,   54,  134,  827,   74,   70,   75,
       75,   85,   83,   85,   76,   75,   85,   83,   76,   77,
       60,   62,   76,   77,  512,  100,  112,   77,   76,   79,
      116,   79,  116,   79,  150,  112,  120,   79,  100,  120,
       62,  124,  149,   62,   62,   62,  135,  136,   62,  148,

      124,  145,   62,   62,  151,   62,   62,   62,  145,  145,
      134,  611,  611,   62,  115,  150,  148,   62,   62,   62,
      115,  149,   62,  115,  152,  154,  163,  115,   62,   62,
      115,  157,   62,  163,   62,   62,   62,  151,  148,  135,
      136,  150,  153,  164,  164,  149,  164,  152,  154,  150,
      155,  164,  196,  152,  135,  136,  156,  149,  196,  188,
      157,  188,  153,  151,  148,  196,  252,  185,  201,  151,
      155,  152,  154,  201,  153,  264,  156,  152,  185,  207,
      405,  207,  217,  218,  157,  153,  217,  218,  405,  152,
      154,  207,  267,  155,  281,  271,  157,  283,  281,  156,

      153,  263,  286,  265,  614,  252,  386,  153,  264,  283,
      828,  286,  266,  614,  271,  155,  262,  270,  268,  252,
      267,  156,  158,  262,  262,  262,  262,  262,  262,  262,
      262,  272,  265,  263,  264,  270,  263,  271,  266,  158,
      264,  829,  158,  269,  267,  158,  268,  273,  387,  272,
      272,  158,  830,  158,  158,  158,  265,  267,  270,  263,
      271,  158,  266,  386,  263,  158,  263,  831,  265,  158,
      268,  269,  272,  272,  273,  158,  275,  266,  276,  158,
      158,  158,  270,  268,  274,  277,  278,  158,  279,  387,
      398,  832,  409,  275,  833,  269,  272,  399,  273,  395,

      620,  523,  277,  277,  274,  277,  276,  620,  269,  523,
      404,  399,  273,  278,  278,  275,  279,  835,  511,  395,
      398,  279,  409,  836,  277,  394,  277,  274,  277,  400,
      276,  615,  394,  394,  394,  394,  394,  278,  278,  404,
      279,  275,  395,  276,  401,  397,  398,  279,  409,  274,
      277,  278,  400,  279,  280,  398,  424,  409,  402,  511,
      424,  837,  406,  404,  395,  397,  403,  517,  698,  698,
      406,  280,  280,  280,  280,  404,  400,  401,  615,  517,
      280,  280,  280,  280,  699,  699,  280,  280,  397,  280,
      402,  406,  838,  280,  400,  280,  280,  280,  403,  403,

      407,  408,  410,  401,  280,  280,  280,  280,  411,  401,
      397,  522,  280,  280,  662,  406,  402,  280,  841,  280,
      407,  703,  410,  402,  403,  403,  408,  406,  413,  412,
      842,  403,  662,  411,  520,  518,  616,  411,  411,  522,
      507,  507,  507,  407,  507,  410,  567,  846,  413,  412,
      408,  567,  518,  848,  849,  414,  520,  411,  415,  853,
      413,  411,  412,  522,  411,  407,  408,  410,  703,  704,
      525,  413,  412,  411,  518,  414,  522,  689,  415,  616,
      520,  689,  839,  519,  706,  414,  413,  414,  412,  525,
      415,  415,  706,  413,  412,  513,  855,  521,  414,  520,

      518,  415,  513,  513,  513,  513,  513,  513,  513,  513,
      840,  414,  525,  414,  529,  519,  415,  415,  764,  521,
      414,  839,  764,  415,  416,  622,  856,  704,  530,  521,
      857,  858,  416,  528,  859,  525,  860,  861,  416,  862,
      865,  519,  531,  521,  416,  622,  529,  416,  519,  416,
      530,  808,  528,  416,  416,  521,  416,  416,  621,  532,
      866,  528,  521,  864,  531,  712,  867,  416,  622,  840,
      868,  416,  529,  416,  530,  528,  871,  416,  863,  529,
      416,  532,  416,  416,  624,  528,  621,  625,  531,  416,
      622,  532,  808,  530,  628,  608,  608,  608,  528,  608,

      712,  631,  872,  808,  624,  532,  625,  531,  873,  874,
      621,  628,  875,  876,  864,  713,  714,  532,  631,  877,
      631,  878,  879,  621,  532,  535,  880,  624,  712,  625,
      712,  881,  882,  628,  884,  863,  886,  887,  888,  889,
      631,  890,  535,  631,  535,  891,  892,  535,  894,  624,
      713,  714,  625,  535,  893,  895,  636,  535,  896,  628,
      898,  900,  901,  902,  535,  879,  631,  535,  904,  880,
      905,  535,  906,  636,  910,  636,  636,  535,  713,  714,
      713,  714,  911,  535,  636,  912,  913,  914,  915,  916,
      535,  917,  918,  919,  920,  636,  921,  922,  636,  636,

      923,  925,  928,  929,  894,  893,  930,  931,  636,  905,
      932,  934,  936,  937,  938,  942,  943,  824,  823,  906,
      822,  636,  821,  819,  817,  815,  814,  813,  807,  915,
      806,  805,  804,  803,  802,  801,  800,  799,  797,  795,
      794,  914,  941,  941,  944,  944,  945,  945,  946,  946,
      947,  947,  948,  948,  949,  949,  950,  950,  791,  789,
      788,  787,  786,  784,  782,  781,  780,  779,  778,  776,
      775,  774,  773,  770,  766,  765,  763,  762,  759,  758,
      757,  755,  754,  753,  752,  751,  749,  747,  745,  744,
      743,  742,  741,  740,  738,  736,  735,  734,  733,  732,

      730,  727,  726,  725,  724,  723,  721,  720,  718,  717,
      716,  715,  710,  708,  707,  702,  701,  700,  697,  695,
      693,  692,  691,  690,  688,  685,  683,  682,  681,  679,
      678,  677,  675,  673,  672,  671,  670,  669,  668,  667,
      666,  665,  664,  663,  658,  657,  656,  655,  654,  652,
      648,  644,  643,  642,  641,  638,  637,  626,  623,  617,
      613,  610,  606,  604,  603,  601,  600,  598,  597,  596,
      595,  594,  593,  591,  590,  588,  587,  586,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  575,  574,  572,
      571,  570,  569,  566,  565,  564,  563,  562,  561,  560,

      559,  558,  557,  556,  555,  553,  552,  551,  550,  548,
      547,  546,  545,  543,  542,  541,  540,  539,  538,  537,
      536,  534,  533,  527,  526,  524,  516,  514,  510,  509,
      508,  506,  505,  504,  503,  502,  501,  500,  499,  498,
      497,  496,  495,  494,  493,  492,  490,  489,  488,  486,
      484,  483,  482,  480,  479,  478,  477,  476,  473,  472,
      471,  469,  468,  466,  465,  464,  462,  461,  460,  459,
      458,  457,  456,  454,  453,  451,  450,  448,  447,  446,
      445,  444,  443,  441,  439,  438,  436,  435,  434,  432,
      431,  430,  429,  427,  426,  423,  422,  421,  420,  419,

      418,  417,  396,  385,  384,  383,  381,  380,  378,  377,
      375,  374,  373,  372,  371,  370,  369,  368,  367,  365,
      363,  362,  361,  360,  359,  358,  357,  356,  355,  354,
      353,  352,  351,  349,  348,  347,  346,  344,  342,  341,
      340,  339,  338,  337,  336,  335,  334,  333,  332,  331,
      330,  329,  328,  327,  325,  324,  322,  321,  320,  319,
      318,  317,  316,  315,  314,  313,  312,  311,  310,  309,
      308,  307,  306,  305,  304,  303,  302,  301,  300,  299,
      298,  297,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  285,  258,  257,  256,  255,  254,  253,  251,  250,

      249,  248,  247,  246,  245,  244,  243,  242,  241,  240,
      239,  238,  237,  236,  235,  234,  233,  232,  231,  229,
      228,  227,  226,  225,  224,  223,  222,  221,  220,  219,
      216,  215,  214,  213,  212,  211,  210,  209,  208,  206,
      205,  204,  203,  202,  200,  199,  198,  197,  195,  194,
      193,  192,  191,  190,  189,  187,  183,  182,  181,  179,
      178,  176,  175,  174,  173,  172,  171,  170,  169,  168,
      167,  166,  165,  162,  161,  159,  146,  143,  142,  141,
      140,  138,  132,  129,  126,  123,  122,  121,  119,  118,
      117,  114,  113,  111,  110,  109,  108,  107,  105,  104,

      103,  102,  101,   99,   98,   97,   96,   94,   93,   92,
       91,   90,   89,   88,   87,   86,   84,   81,   80,   78,
       73,   71,   68,   64,   43,   42,   39,   38,   36,   35,
       34,   28,   27,   23,   17,    3,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,
      940,  940,  940,  940,  940,  940,  940,  940,  940,  940,

      940,  940,  940,  940,  940,  940,  940
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[172] =
    {   0,
0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int sieve_flex_debug;
int sieve_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *sievetext;
#line 1 "sieve/sieve-lex.l"
#line 2 "sieve/sieve-lex.l"
/* sieve.l -- sieve lexer
 * Larry Greenfield
 * Ken Murchison
 *
 * Copyright (c) 1994-2017 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any legal
 *    details, please contact
 *      Carnegie Mellon University
 *      Center for Technology Transfer and Enterprise Creation
 *      4615 Forbes Avenue
 *      Suite 302
 *      Pittsburgh, PA  15213
 *      (412) 268-7393, fax: (412) 268-7395
 *      innovation@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "util.h"

#include "sieve/tree.h"
#include "sieve/sieve_interface.h"
#include "sieve/sieve.h"

#define YY_NO_INPUT
#define YY_DECL int sievelex(YYSTYPE *yylval,sieve_script_t *sscript)

static struct buf buf;   /* buffer for multi-line text and quoted strings */
extern int encoded_char; /* used to receive encoded-char feedback from parser */
extern int getdatepart;  /* used to receive start state feedback from parser */

static unsigned long long tonum(const char *str);
static int decode_string(struct buf *buf);
extern void sieveerror(sieve_script_t *, char *);
extern void sieveerror_f(sieve_script_t *, char *fmt, ...);
/* linebreak */
/* non-linebreaking whitespace */
/* UTC offset of timezone +/-hhmm */
/* case-insensitive date-parts */







#line 1226 "sieve/sieve-lex.c"

#define INITIAL 0
#define MULTILINE 1
#define QSTRING 2
#define QCOLLATION 3
#define QRELATION 4
#define QIMPORTANCE 5
#define QTIMEZONE 6
#define QDATEPART 7

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int sievelex_destroy (void );

int sieveget_debug (void );

void sieveset_debug (int debug_flag  );

YY_EXTRA_TYPE sieveget_extra (void );

void sieveset_extra (YY_EXTRA_TYPE user_defined  );

FILE *sieveget_in (void );

void sieveset_in  (FILE * _in_str  );

FILE *sieveget_out (void );

void sieveset_out  (FILE * _out_str  );

			int sieveget_leng (void );

char *sieveget_text (void );

int sieveget_lineno (void );

void sieveset_lineno (int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int sievewrap (void );
#else
extern int sievewrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( sievetext, (size_t) sieveleng, 1, sieveout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( sievein )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( sievein ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, max_size, sievein))==0 && ferror(sievein)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(sievein); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int sievelex (void);

#define YY_DECL int sievelex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after sievetext and sieveleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( sieveleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(sievetext[sieveleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! sievein )
			sievein = stdin;

		if ( ! sieveout )
			sieveout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			sieveensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				sieve_create_buffer(sievein,YY_BUF_SIZE );
		}

		sieve_load_buffer_state( );
		}

	{
#line 106 "sieve/sieve-lex.l"

    /* dot stuffing */
#line 1455 "sieve/sieve-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of sievetext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 941 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1437 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < sieveleng; ++yyl )
				if ( sievetext[yyl] == '\n' )
					
    sievelineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 108 "sieve/sieve-lex.l"
buf_putc(&buf, sievetext[1]);
	YY_BREAK
/* end of multi-line text */
case 2:
/* rule 2 can match eol */
#line 112 "sieve/sieve-lex.l"
/* end of quoted string */
case 3:
YY_RULE_SETUP
#line 114 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  if (encoded_char && !decode_string(&buf)) {
                                      sieveerror_f(sscript,
                                                   "invalid unicode encoding: %s",
                                                   buf_cstring(&buf));
                                  }
                                  yylval->sval = buf_release(&buf);
                                  return STRING;
                              }
	YY_BREAK
/* escaped character */
case 4:
YY_RULE_SETUP
#line 126 "sieve/sieve-lex.l"
buf_putc(&buf, sievetext[1]);
	YY_BREAK
/* any character (including LF) */
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 129 "sieve/sieve-lex.l"
buf_putc(&buf, sievetext[0]);
	YY_BREAK
/* premature EOF */
case YY_STATE_EOF(QSTRING):
case YY_STATE_EOF(MULTILINE):
#line 132 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror(sscript,
                                             "unexpected end of file in string");
                                  buf_free(&buf);
                                  yyterminate();
                              }
	YY_BREAK
/* beginning of multi-line text */
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 141 "sieve/sieve-lex.l"
{
                                  BEGIN MULTILINE;
                                  buf_reset(&buf);
                              }
	YY_BREAK
/* beginning of quoted string */
case 7:
YY_RULE_SETUP
#line 147 "sieve/sieve-lex.l"
{
                                  if (getdatepart) {
                                      BEGIN QDATEPART;
                                      getdatepart = 0;
                                      yyless(0);
                                  }
                                  else {
                                      BEGIN QSTRING;
                                      buf_reset(&buf);
                                  }
                              }
	YY_BREAK
/* number with optional power of 2 suffix */
case 8:
YY_RULE_SETUP
#line 160 "sieve/sieve-lex.l"
{
                                  unsigned long long val = tonum(sievetext);
                                  if (val > INT_MAX) {
                                      sieveerror_f(sscript,
                                                   "number too large %s",
                                                   sievetext);
                                  }
                                  yylval->nval = val;
                                  return NUMBER;
                              }
	YY_BREAK
/* standard control commands - RFC 5228 */
case 9:
YY_RULE_SETUP
#line 172 "sieve/sieve-lex.l"
return IF;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 173 "sieve/sieve-lex.l"
return ELSIF;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 174 "sieve/sieve-lex.l"
return ELSE;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 175 "sieve/sieve-lex.l"
return REQUIRE;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 176 "sieve/sieve-lex.l"
return STOP;
	YY_BREAK
/* standard tests - RFC 5228 */
case 14:
YY_RULE_SETUP
#line 179 "sieve/sieve-lex.l"
return ANYOF;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 180 "sieve/sieve-lex.l"
return ALLOF;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 181 "sieve/sieve-lex.l"
return EXISTS;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 182 "sieve/sieve-lex.l"
return SFALSE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 183 "sieve/sieve-lex.l"
return STRUE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 184 "sieve/sieve-lex.l"
return NOT;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 185 "sieve/sieve-lex.l"
return HEADERT;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 186 "sieve/sieve-lex.l"
return ADDRESS;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 187 "sieve/sieve-lex.l"
return ENVELOPE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 188 "sieve/sieve-lex.l"
return SIZE;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 189 "sieve/sieve-lex.l"
return yylval->nval = OVER;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 190 "sieve/sieve-lex.l"
return yylval->nval = UNDER;
	YY_BREAK
/* standard action commands - RFC 5228 */
case 26:
YY_RULE_SETUP
#line 193 "sieve/sieve-lex.l"
return DISCARD;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 194 "sieve/sieve-lex.l"
return KEEP;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 195 "sieve/sieve-lex.l"
return FILEINTO;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 196 "sieve/sieve-lex.l"
return REDIRECT;
	YY_BREAK
/* copy - RFC 3894 */
case 30:
YY_RULE_SETUP
#line 199 "sieve/sieve-lex.l"
return COPY;
	YY_BREAK
/* comparator-types - RFC 5228 */
case 31:
YY_RULE_SETUP
#line 202 "sieve/sieve-lex.l"
{ BEGIN QCOLLATION; return COMPARATOR; }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 204 "sieve/sieve-lex.l"
;       /* ignore whitespace */
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 205 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = OCTET;
                              }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 209 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = ASCIICASEMAP;
                              }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 213 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = ASCIINUMERIC;
                              }
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 217 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "unknown comparator-name %s",
                                               sievetext);
                              }
	YY_BREAK
/* match-types - RFC 5228 */
case 37:
YY_RULE_SETUP
#line 225 "sieve/sieve-lex.l"
return yylval->nval = IS;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 226 "sieve/sieve-lex.l"
return yylval->nval = CONTAINS;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 227 "sieve/sieve-lex.l"
return yylval->nval = MATCHES;
	YY_BREAK
/* regex - draft-ietf-sieve-regex */
case 40:
YY_RULE_SETUP
#line 230 "sieve/sieve-lex.l"
return yylval->nval = REGEX;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 231 "sieve/sieve-lex.l"
return yylval->nval = QUOTEREGEX;
	YY_BREAK
/* extlists - RFC 6134 */
case 42:
YY_RULE_SETUP
#line 234 "sieve/sieve-lex.l"
return yylval->nval = LIST;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 235 "sieve/sieve-lex.l"
return VALIDEXTLIST;
	YY_BREAK
/* address-parts - RFC 5228 */
case 44:
YY_RULE_SETUP
#line 238 "sieve/sieve-lex.l"
return yylval->nval = ALL;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 239 "sieve/sieve-lex.l"
return yylval->nval = LOCALPART;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 240 "sieve/sieve-lex.l"
return yylval->nval = DOMAIN;
	YY_BREAK
/* subaddress - RFC 5233 */
case 47:
YY_RULE_SETUP
#line 243 "sieve/sieve-lex.l"
return yylval->nval = USER;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 244 "sieve/sieve-lex.l"
return yylval->nval = DETAIL;
	YY_BREAK
/* body - RFC 5173 */
case 49:
YY_RULE_SETUP
#line 247 "sieve/sieve-lex.l"
return BODY;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 248 "sieve/sieve-lex.l"
return yylval->nval = RAW;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 249 "sieve/sieve-lex.l"
return yylval->nval = TEXT;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 250 "sieve/sieve-lex.l"
return yylval->nval = CONTENT;
	YY_BREAK
/* environment - RFC 5183 */
case 53:
YY_RULE_SETUP
#line 253 "sieve/sieve-lex.l"
return ENVIRONMENT;
	YY_BREAK
/* variables - RFC 5229 */
case 54:
YY_RULE_SETUP
#line 256 "sieve/sieve-lex.l"
return STRINGT;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 257 "sieve/sieve-lex.l"
return SET;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 258 "sieve/sieve-lex.l"
return yylval->nval = LOWER;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 259 "sieve/sieve-lex.l"
return yylval->nval = UPPER;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 260 "sieve/sieve-lex.l"
return yylval->nval = LOWERFIRST;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 261 "sieve/sieve-lex.l"
return yylval->nval = UPPERFIRST;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 262 "sieve/sieve-lex.l"
return yylval->nval = QUOTEWILDCARD;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 263 "sieve/sieve-lex.l"
return yylval->nval = LENGTH;
	YY_BREAK
/* vacation - RFC 5230 */
case 62:
YY_RULE_SETUP
#line 266 "sieve/sieve-lex.l"
return VACATION;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 267 "sieve/sieve-lex.l"
return DAYS;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 268 "sieve/sieve-lex.l"
return ADDRESSES;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 269 "sieve/sieve-lex.l"
return SUBJECT;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 270 "sieve/sieve-lex.l"
return FROM;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 271 "sieve/sieve-lex.l"
return HANDLE;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 272 "sieve/sieve-lex.l"
return MIME;
	YY_BREAK
/* vacation-seconds - RFC 6131 */
case 69:
YY_RULE_SETUP
#line 275 "sieve/sieve-lex.l"
return SECONDS;
	YY_BREAK
/* relational - RFC 5231 */
case 70:
YY_RULE_SETUP
#line 278 "sieve/sieve-lex.l"
{ BEGIN QRELATION; return yylval->nval = COUNT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 279 "sieve/sieve-lex.l"
{ BEGIN QRELATION; return yylval->nval = VALUE; }
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 281 "sieve/sieve-lex.l"
;        /* ignore whitespace */
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 282 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = EQ; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 283 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = NE; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 284 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = GT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 285 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = GE; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 286 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 287 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LE; }
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 288 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid relational-match %s",
                                               sievetext);
                              }
	YY_BREAK
/* imap4flags - RFC 5232 */
case 80:
YY_RULE_SETUP
#line 296 "sieve/sieve-lex.l"
return yylval->nval = SETFLAG;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 297 "sieve/sieve-lex.l"
return yylval->nval = ADDFLAG;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 298 "sieve/sieve-lex.l"
return yylval->nval = REMOVEFLAG;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 299 "sieve/sieve-lex.l"
return yylval->nval = HASFLAG;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 300 "sieve/sieve-lex.l"
return FLAGS;
	YY_BREAK
/* imapflags - draft-melnikov-sieve-imapflags-04 */
case 85:
YY_RULE_SETUP
#line 303 "sieve/sieve-lex.l"
return yylval->nval = MARK;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 304 "sieve/sieve-lex.l"
return yylval->nval = UNMARK;
	YY_BREAK
/* date - RFC 5260 */
case 87:
YY_RULE_SETUP
#line 307 "sieve/sieve-lex.l"
return DATE;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 308 "sieve/sieve-lex.l"
return ORIGINALZONE;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 309 "sieve/sieve-lex.l"
{ BEGIN QTIMEZONE; return ZONE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 310 "sieve/sieve-lex.l"
{ getdatepart = 1; return CURRENTDATE; }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 312 "sieve/sieve-lex.l"
;        /* ignore whitespace */
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 313 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  int tz = atoi(sievetext+1); /* skip leading " */
                                  yylval->nval = 60 * (tz / 100) + (tz % 100);
                                  return TIMEZONE;
                              }
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 319 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid time-zone %s", sievetext);
                              }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 325 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = YEARP;    }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 326 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = MONTHP;   }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 327 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = DAYP;     }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 328 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = DATEP;    }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 329 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = JULIAN;   }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 330 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = HOURP;    }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 331 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = MINUTEP;  }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 332 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = SECONDP;  }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 333 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = TIMEP;    }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 334 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = ISO8601;  }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 335 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = STD11;    }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 336 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = ZONEP;    }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 337 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = WEEKDAYP; }
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 338 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid date-part %s", sievetext);
                              }
	YY_BREAK
/* index - RFC 5260 */
case 108:
YY_RULE_SETUP
#line 346 "sieve/sieve-lex.l"
return INDEX;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 347 "sieve/sieve-lex.l"
return LAST;
	YY_BREAK
/* editheader - RFC 5293 */
case 110:
YY_RULE_SETUP
#line 350 "sieve/sieve-lex.l"
return ADDHEADER;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 351 "sieve/sieve-lex.l"
return DELETEHEADER;
	YY_BREAK
/*   :index               defined in 'index' */
/*   :last                defined in 'index' */
/* [e]reject - RFC 5429 */
case 112:
YY_RULE_SETUP
#line 356 "sieve/sieve-lex.l"
return yylval->nval = REJCT;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 357 "sieve/sieve-lex.l"
return yylval->nval = EREJECT;
	YY_BREAK
/* enotify - RFC 5435 */
case 114:
YY_RULE_SETUP
#line 360 "sieve/sieve-lex.l"
return NOTIFYMETHODCAPABILITY;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 361 "sieve/sieve-lex.l"
return VALIDNOTIFYMETHOD;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 362 "sieve/sieve-lex.l"
return NOTIFY;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 363 "sieve/sieve-lex.l"
return OPTIONS;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 364 "sieve/sieve-lex.l"
return MESSAGE;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 365 "sieve/sieve-lex.l"
return yylval->nval = ENCODEURL;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 366 "sieve/sieve-lex.l"
{ BEGIN QIMPORTANCE; return IMPORTANCE; }
	YY_BREAK
case 121:
/* rule 121 can match eol */
YY_RULE_SETUP
#line 368 "sieve/sieve-lex.l"
;      /* ignore whitespace */
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 369 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = HIGH;   }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 370 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = NORMAL; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 371 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LOW;    }
	YY_BREAK
case 125:
/* rule 125 can match eol */
YY_RULE_SETUP
#line 372 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid importance %s", sievetext);
                              }
	YY_BREAK
/* notify - draft-martin-sieve-notify-01 */
case 126:
YY_RULE_SETUP
#line 379 "sieve/sieve-lex.l"
return DENOTIFY;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 380 "sieve/sieve-lex.l"
return METHOD;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 381 "sieve/sieve-lex.l"
return ID;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 382 "sieve/sieve-lex.l"
return yylval->nval = LOW;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 383 "sieve/sieve-lex.l"
return yylval->nval = NORMAL;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 384 "sieve/sieve-lex.l"
return yylval->nval = HIGH;
	YY_BREAK
/* ihave - RFC 5463 */
case 132:
YY_RULE_SETUP
#line 387 "sieve/sieve-lex.l"
return IHAVE;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 388 "sieve/sieve-lex.l"
return ERROR;
	YY_BREAK
/* mailbox - RFC 5490 */
case 134:
YY_RULE_SETUP
#line 391 "sieve/sieve-lex.l"
return MAILBOXEXISTS;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 392 "sieve/sieve-lex.l"
return CREATE;
	YY_BREAK
/* mboxmetadata - RFC 5490 */
case 136:
YY_RULE_SETUP
#line 395 "sieve/sieve-lex.l"
return yylval->nval = METADATA;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 396 "sieve/sieve-lex.l"
return METADATAEXISTS;
	YY_BREAK
/* servermetadata - RFC 5490 */
case 138:
YY_RULE_SETUP
#line 399 "sieve/sieve-lex.l"
return yylval->nval = SERVERMETADATA;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 400 "sieve/sieve-lex.l"
return SERVERMETADATAEXISTS;
	YY_BREAK
/* redirect-deliverby - RFC 6009 */
case 140:
YY_RULE_SETUP
#line 403 "sieve/sieve-lex.l"
return BYTIMEREL;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 404 "sieve/sieve-lex.l"
return BYTIMEABS;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 405 "sieve/sieve-lex.l"
return BYMODE;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 406 "sieve/sieve-lex.l"
return BYTRACE;
	YY_BREAK
/* redirect-dsn - RFC 6009 */
case 144:
YY_RULE_SETUP
#line 409 "sieve/sieve-lex.l"
return DSNNOTIFY;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 410 "sieve/sieve-lex.l"
return DSNRET;
	YY_BREAK
/* include - RFC 6609 */
case 146:
YY_RULE_SETUP
#line 413 "sieve/sieve-lex.l"
return INCLUDE;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 414 "sieve/sieve-lex.l"
return yylval->nval = PERSONAL;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 415 "sieve/sieve-lex.l"
return yylval->nval = GLOBAL;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 416 "sieve/sieve-lex.l"
return OPTIONAL;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 417 "sieve/sieve-lex.l"
return ONCE;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 418 "sieve/sieve-lex.l"
return RETURN;
	YY_BREAK
/* duplicate - RFC 7352 */
case 152:
YY_RULE_SETUP
#line 421 "sieve/sieve-lex.l"
return DUPLICATE;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 422 "sieve/sieve-lex.l"
return yylval->nval = HEADER;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 423 "sieve/sieve-lex.l"
return yylval->nval = UNIQUEID;
	YY_BREAK
/*   :handle              defined in 'vacation' */
/*   :seconds             defined in 'vacation-seconds' */
/*   :last                defined in 'index' */
/* special-use - RFC 8579 */
case 155:
YY_RULE_SETUP
#line 429 "sieve/sieve-lex.l"
return SPECIALUSEEXISTS;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 430 "sieve/sieve-lex.l"
return SPECIALUSE;
	YY_BREAK
/* fcc - RFC 8580 */
case 157:
YY_RULE_SETUP
#line 433 "sieve/sieve-lex.l"
return FCC;
	YY_BREAK
/* draft-gondwana-sieve-mailboxid */
case 158:
YY_RULE_SETUP
#line 436 "sieve/sieve-lex.l"
return MAILBOXIDEXISTS;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 437 "sieve/sieve-lex.l"
return MAILBOXID;
	YY_BREAK
/* x-cyrus-log */
case 160:
YY_RULE_SETUP
#line 440 "sieve/sieve-lex.l"
return LOG;
	YY_BREAK
/* x-cyrus-jmapquery */
case 161:
YY_RULE_SETUP
#line 443 "sieve/sieve-lex.l"
return JMAPQUERY;
	YY_BREAK
/* x-cyrus-snooze */
case 162:
YY_RULE_SETUP
#line 446 "sieve/sieve-lex.l"
return SNOOZE;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 447 "sieve/sieve-lex.l"
return MAILBOX;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 448 "sieve/sieve-lex.l"
return ADDFLAGS;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 449 "sieve/sieve-lex.l"
return REMOVEFLAGS;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 450 "sieve/sieve-lex.l"
return WEEKDAYS;
	YY_BREAK
/*   :mailboxid            defined in draft-gondwana-sieve-mailboxid */
case 167:
/* rule 167 can match eol */
YY_RULE_SETUP
#line 453 "sieve/sieve-lex.l"
;  /* ignore bracketed comments */
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 454 "sieve/sieve-lex.l"
;                /* ignore hash comments */
	YY_BREAK
case 169:
/* rule 169 can match eol */
YY_RULE_SETUP
#line 455 "sieve/sieve-lex.l"
;          /* ignore whitespace */
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 456 "sieve/sieve-lex.l"
return sievetext[0];
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 458 "sieve/sieve-lex.l"
ECHO;
	YY_BREAK
#line 2519 "sieve/sieve-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(QCOLLATION):
case YY_STATE_EOF(QRELATION):
case YY_STATE_EOF(QIMPORTANCE):
case YY_STATE_EOF(QTIMEZONE):
case YY_STATE_EOF(QDATEPART):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed sievein at a new source and called
			 * sievelex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = sievein;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( sievewrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * sievetext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of sievelex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					sieverealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			sieverestart(sievein  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) sieverealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 941 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 941 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (flex_int16_t) yy_c];
	yy_is_jam = (yy_current_state == 940);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					sieverestart(sievein );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( sievewrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve sievetext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    sievelineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void sieverestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        sieveensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            sieve_create_buffer(sievein,YY_BUF_SIZE );
	}

	sieve_init_buffer(YY_CURRENT_BUFFER,input_file );
	sieve_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void sieve_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		sievepop_buffer_state();
	 *		sievepush_buffer_state(new_buffer);
     */
	sieveensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	sieve_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (sievewrap()) processing, but the only time this flag
	 * is looked at is after sievewrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void sieve_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	sievein = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE sieve_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) sievealloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) sievealloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_create_buffer()" );

	b->yy_is_our_buffer = 1;

	sieve_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with sieve_create_buffer()
 * 
 */
    void sieve_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		sievefree((void *) b->yy_ch_buf  );

	sievefree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a sieverestart() or at EOF.
 */
    static void sieve_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	sieve_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then sieve_init_buffer was _probably_
     * called from sieverestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void sieve_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		sieve_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void sievepush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	sieveensure_buffer_stack();

	/* This block is copied from sieve_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from sieve_switch_to_buffer. */
	sieve_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void sievepop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	sieve_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		sieve_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void sieveensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)sievealloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in sieveensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)sieverealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in sieveensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE sieve_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) sievealloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	sieve_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to sievelex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       sieve_scan_bytes() instead.
 */
YY_BUFFER_STATE sieve_scan_string (yyconst char * yystr )
{
    
	return sieve_scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to sievelex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE sieve_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) sievealloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in sieve_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = sieve_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in sieve_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up sievetext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		sievetext[sieveleng] = (yy_hold_char); \
		(yy_c_buf_p) = sievetext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		sieveleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int sieveget_lineno  (void)
{
    
    return sievelineno;
}

/** Get the input stream.
 * 
 */
FILE *sieveget_in  (void)
{
        return sievein;
}

/** Get the output stream.
 * 
 */
FILE *sieveget_out  (void)
{
        return sieveout;
}

/** Get the length of the current token.
 * 
 */
int sieveget_leng  (void)
{
        return sieveleng;
}

/** Get the current token.
 * 
 */

char *sieveget_text  (void)
{
        return sievetext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void sieveset_lineno (int  _line_number )
{
    
    sievelineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see sieve_switch_to_buffer
 */
void sieveset_in (FILE *  _in_str )
{
        sievein = _in_str ;
}

void sieveset_out (FILE *  _out_str )
{
        sieveout = _out_str ;
}

int sieveget_debug  (void)
{
        return sieve_flex_debug;
}

void sieveset_debug (int  _bdebug )
{
        sieve_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from sievelex_destroy(), so don't allocate here.
     */

    /* We do not touch sievelineno unless the option is enabled. */
    sievelineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    sievein = stdin;
    sieveout = stdout;
#else
    sievein = NULL;
    sieveout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * sievelex_init()
     */
    return 0;
}

/* sievelex_destroy is for both reentrant and non-reentrant scanners. */
int sievelex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		sieve_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		sievepop_buffer_state();
	}

	/* Destroy the stack itself. */
	sievefree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * sievelex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *sievealloc (yy_size_t  size )
{
			return malloc(size);
}

void *sieverealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void sievefree (void * ptr )
{
			free( (char *) ptr );	/* see sieverealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 458 "sieve/sieve-lex.l"



/* convert numerical string w/units to unsigned long */
static unsigned long long tonum(const char *str)
{
    char *units;
    unsigned long long val = strtoull(str, &units, 10);

    if (*units && errno != ERANGE) {
        switch (toupper(*units)) {
        case 'K': val *= (1ULL << 10); break;
        case 'M': val *= (1ULL << 20); break;
        case 'G': val *= (1ULL << 30); break;
            /* for future use */
        case 'T': val *= (1ULL << 40); break;
        case 'P': val *= (1ULL << 50); break;
        case 'E': val *= (1ULL << 60); break;
        default: break;
        }
    }

    return val;
}

/* convert unicode to sequence of UTF-8 characters */
static size_t unicode_to_utf8(unsigned char buf[], unsigned int code)
{
    if (code <= 0x7F) {
        buf[0] = code;
        return 1;
    }
    if (code <= 0x7FF) {
        buf[0] = 0xC0 | (code >> 6);            /* 110xxxxx */
        buf[1] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 2;
    }
    if (code < 0xE000 && code > 0xD7FF) return 0;
    if (code <= 0xFFFF) {
        buf[0] = 0xE0 | (code >> 12);           /* 1110xxxx */
        buf[1] = 0x80 | ((code >> 6) & 0x3F);   /* 10xxxxxx */
        buf[2] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 3;
    }
    if (code <= 0x10FFFF) {
        buf[0] = 0xF0 | (code >> 18);           /* 11110xxx */
        buf[1] = 0x80 | ((code >> 12) & 0x3F);  /* 10xxxxxx */
        buf[2] = 0x80 | ((code >> 6) & 0x3F);   /* 10xxxxxx */
        buf[3] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 4;
    }
    return 0;
}

/*
  Decode "encoded-character" strings having one of the following two forms:

  encoded-arb-octets   =  "${hex:" hex-pair-seq "}"
  hex-pair-seq         =  *blank hex-pair *(1*blank hex-pair) *blank
  hex-pair             =  1*2HEXDIG

  encoded-unicode-char =  "${unicode:" unicode-hex-seq "}"
  unicode-hex-seq      =  *blank unicode-hex *(1*blank unicode-hex) *blank
  unicode-hex          =  1*HEXDIG
   
  blank                =  WSP / CRLF
  WSP                  =  SP / HTAB 
  HEXDIG               =  DIGIT / "A" / "B" / "C" / "D" / "E" / "F"
*/
static int decode_string(struct buf *buf)
{
    static struct buf decode_buf = BUF_INITIALIZER;
    const char *cp, *enc_start;

    for (cp = buf_cstring(buf); (enc_start = strstr(cp, "${")); ) {
        unsigned is_unicode = 0;
        size_t len;

        cp = enc_start + 2;

        if (!strncasecmp(cp, "hex:", 4)) {
            cp += 4;
        }
        else if (!strncasecmp(cp, "unicode:", 8)) {
            is_unicode = 1;
            cp += 8;
        }
        else {
            /* not coded */
            continue;
        }

        /* eat leading whitespace */
        while (isspace(*cp)) cp++;

        /* sanity check "encoded" data (being liberal in accepting 'a' - 'f') */
        len = strspn(cp, "0123456789ABCDEFabcdef \t\r\n");
        if (!isxdigit(*cp) || cp[len] != '}') continue;

        /* decode characters */
        buf_reset(&decode_buf);
        do {
            unsigned int ndigits, code;

            for (ndigits = 0, code = 0; isxdigit(*cp); ndigits++, cp++) {
                unsigned int digit = 
                    (*cp > '9') ? 10 + toupper(*cp) - 'A' : *cp - '0';

                code = (code << 4) + digit;
            }

            if (is_unicode) {
                unsigned char utf8[4];

                len = unicode_to_utf8(utf8, code);
                if (!len) {
                    /* invalid UTF-8 encoding - error */
                    return 0;
                }

                /* append decoded unicode char(s) to buffer */
                buf_appendmap(&decode_buf, (char *) utf8, len);
            }
            else if (ndigits > 2) {
                /* too many hex digits - treat as not coded */
                buf_reset(&decode_buf);
                cp += len + 1;
                break;
            }
            else {
                /* append decoded hex char to buffer */
                buf_putc(&decode_buf, code);
            }

            /* eat trailing whitespace */
            while (isspace(*cp)) cp++;

        } while (*cp != '}');

        if ((len = buf_len(&decode_buf))) {
            /* replace the encoded string with its decoded value */
            size_t offset = enc_start - buf_base(buf);

            buf_remove(buf, offset, cp - enc_start + 1);
            buf_insert(buf, offset, &decode_buf);

            /* buffer may have been reallocated - reposition our pointer */
            cp = buf_cstring(buf) + offset + len;
        }
    }

    return 1;
}

